@@ -13,7 +13,7 @@ PhilipRBrenan@gmail.com, 2016, Perl License. www.appaapps.com
 
 
 package Math::Algebra::Symbols::Term;
-$VERSION=1.24;
+$VERSION=1.25;
 use Carp;
 use Math::BigInt;
 #HashUtil use Hash::Util qw(lock_hash);
@@ -70,7 +70,7 @@ sub newFromString($)
     my $z = new()->c($c)->d($d)->i($i);
 
     my $b = $5;
-    for (;$b =~ /^([a-z]+)(?:\*\*)?(\d+)?(?:\*)?(.*)$/i;)
+    for (;$b =~ /^(\pL+)(?:\*\*)?(\d+)?(?:\*)?(.*)$/i;)                         # 2016/01/20 21:02:35 unicode support
      {$b = $3;
       $z->{v}{$1} = $2 if     defined($2);
       $z->{v}{$1} = 1  unless defined($2);
